.. Bedrock Server Manager documentation master file

Bedrock Server Manager
======================

Welcome to the Bedrock Server Manager documentation!

This documentation is designed to help you understand and use the Bedrock Server Manager effectively.

Browse through the sections below to find various information about Bedrock Server Manager, including general information, CLI commands, web interface, plugins, and developer documentation.

.. toctree::
   :maxdepth: 2
   :caption: General Information

   general/introduction.md
   cli/general.md
   web/general.md
   general/plugins.md
   general/troubleshooting.md

.. toctree::
   :maxdepth: 2
   :caption: Changelog

   changelog

.. toctree::
   :maxdepth: 2
   :caption: Extras

   extras/installation.md
   extras/docker.md
   extras/install_content.md
   extras/web_extras.md
   extras/websockets.md
   web/theming.md

.. toctree::
   :maxdepth: 2
   :caption: CLI Commands

   cli/commands
   cli/api_client_commands

.. toctree::
   :maxdepth: 2
   :caption: Plugins

   plugins/introduction.md
   developer/plugins/introduction.md
   plugins/plugin_apis.md
   developer/plugins/plugin_base
   developer/plugins/plugin_manager

.. toctree::
   :maxdepth: 2
   :caption: Developer Documentation

   developer/api/api
   developer/classes/classes
   developer/core/core


Source Code: `Github <https://github.com/DMedina559/bedrock-server-manager>`_
